dio_file_uploader library

A en_file_uploader plugin to handle via dio the file upload.

Classes

DioChunkedFileHandler
DioChunkedFileHandler handle the file upload in chunks
DioFileHandler
DioFileHandler handle the file upload using the dio.Dio.request
DioRestorableChunkedFileHandler
DioRestorableChunkedFileHandler handle the file upload in chunk with the capability to retry the upload from the last chunk sent.
SocketChunkedFileHandler<ResponseType>
A common interface for any plugin that wants to handle file uploads using a socket client.
SocketFileHandler<ResponseType>
A common interface for any plugin that wants to handle file uploads using a socket client.
SocketRestorableChunkedFileHandler<ResponseType>
A common interface for any plugin that wants to handle file uploads using a socket client.

Typedefs

ChunkHeadersCallback = Map<String, String> Function(FileChunk chunk)
compose request headers from FileChunk
ChunkParser<T> = ChunkParser<Response<T>>
callback to validate chunk upload
ChunkPathCallback = String Function(FileUploadPresentationResponse presentation, FileChunk chunk)
compose request upload chunks path from on FileUploadPresentationResponse and FileChunk
FileHeadersCallback = Map<String, String>? Function(XFile file)
compose request headers from XFile
PresentHeadersCallback = Map<String, String> Function(XFile file)
compose request headers from XFile
PresentParser<T> = PresentParser<Response<T>>
callback to convert dio.Response into FileUploadPresentationResponse
RestorableChunkHeadersCallback = Map<String, String> Function(FileUploadPresentationResponse presentation, FileChunk chunk)
compose request upload chunks headers from FileUploadPresentationResponse and FileChunk
StatusHeadersCallback = Map<String, String> Function(FileUploadPresentationResponse presentation)
compose request status headers from FileUploadPresentationResponse
StatusParser<T> = StatusParser<Response<T>>
callback to convert dio.Response into FileUploadStatusResponse
StatusPathCallback = String Function(FileUploadPresentationResponse presentation)
compose request status path from on FileUploadPresentationResponse