SocketChunkedFileHandler<ResponseType> class abstract

A common interface for any plugin that wants to handle file uploads using a socket client.

Implementers

Constructors

SocketChunkedFileHandler({required XFile file, required String path, int? chunkSize, String method = kFileUploadMethod, String fileKey = kFileKey, ChunkHeadersCallback? headers, String? body, ChunkParser<ResponseType> chunkParser = kChunkParser})
A common interface for any plugin that wants to handle file uploads using a socket client.
const

Properties

body String?
request body
final
chunkParser → ChunkParser<ResponseType>
callback to validate chunk upload
final
chunkSize int?
chunk size, if null defaultChunkSize is used
finalinherited
file → XFile
The file to upload.
no setterinherited
fileKey String
request key for file
final
hashCode int
The hash code for this object.
no setterinherited
headers ChunkHeadersCallback?
request headers
final
method String
request method, default to POST
final
originalFile → XFile
The file to upload.
finalinherited
path String
request path
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadChunk(FileChunk chunk, {ProgressCallback? onProgress}) Future<void>
method to handle the upload of a FileChunk
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited