SocketFileHandler<ResponseType> class abstract

A common interface for any plugin that wants to handle file uploads using a socket client.

Implementers

Constructors

SocketFileHandler({required XFile file, required String path, String method = kFileUploadMethod, Map<String, String>? headers, String? body, String fileKey = kFileKey, FileHeadersCallback? headersCallback, ChunkParser<ResponseType> fileParser = kChunkParser})
A common interface for any plugin that wants to handle file uploads using a socket client.
const

Properties

body String?
request body
final
file → XFile
The file to upload.
no setterinherited
fileKey String
request key for file
final
fileParser → ChunkParser<ResponseType>
callback to validate chunk upload
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
request headers
final
headersCallback FileHeadersCallback?
request headers
final
method String
request method, default to POST
final
originalFile → XFile
The file to upload.
finalinherited
path String
request path
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(XFile file, {ProgressCallback? onProgress}) Future<void>
Method for uploading the entire file.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited