originalFile property

XFile originalFile
finalinherited

The file to upload.

The file may differ from the one that will be sent if any transformations have been applied.

Implementation

final XFile originalFile;