upload abstract method

Future<void> upload(
  1. XFile file, {
  2. ProgressCallback? onProgress,
})
inherited

Method for uploading the entire file.

onProgress is a callback that will be called with the progress of the upload. The callback will receive the current progress and the total size of the file.

controller.upload(onProgress: (progress, total) {
  print('Upload progress: $progress of $total');
});

Implementation

Future<void> upload(
  XFile file, {
  ProgressCallback? onProgress,
});