SocketRestorableChunkedFileHandler<ResponseType> class abstract

A common interface for any plugin that wants to handle file uploads using a socket client.

Implementers

Constructors

SocketRestorableChunkedFileHandler({required XFile file, required String presentPath, required ChunkPathCallback chunkPath, required StatusPathCallback statusPath, required PresentParser<ResponseType> presentParser, required StatusParser<ResponseType> statusParser, int? chunkSize, String presentMethod = kPresentMethod, String chunkMethod = kChunkMethod, String statusMethod = kStatusMethod, Map<String, String>? presentHeaders, PresentHeadersCallback? presentHeadersCallback, RestorableChunkHeadersCallback? chunkHeaders, StatusHeadersCallback? statusHeaders, String? presentBody, String? chunkBody, String? statusBody, String fileKey = kFileKey, ChunkParser<ResponseType> chunkParser = kChunkParser})
A common interface for any plugin that wants to handle file uploads using a socket client.
const

Properties

chunkBody String?
body used on chunk upload
final
chunkHeaders RestorableChunkHeadersCallback?
headers used on chunk upload
final
chunkMethod String
method used on chunk upload
final
chunkParser → ChunkParser<ResponseType>
callback to validate chunk upload
final
chunkPath ChunkPathCallback
path used on chunk upload
final
chunkSize int?
chunk size, if null defaultChunkSize is used
finalinherited
file → XFile
The file to upload.
no setterinherited
fileKey String
request key for file
final
hashCode int
The hash code for this object.
no setterinherited
originalFile → XFile
The file to upload.
finalinherited
presentBody String?
body used on presentation
final
presentHeaders Map<String, String>?
headers used on presentation
final
presentHeadersCallback PresentHeadersCallback?
headers used on presentation
final
presentMethod String
method used on presentation
final
presentParser → PresentParser<ResponseType>
callback to convert ResponseType into FileUploadPresentationResponse
final
presentPath String
path used on presentation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusBody String?
body used on status
final
statusHeaders StatusHeadersCallback?
headers used on status
final
statusMethod String
method used on status
final
statusParser → StatusParser<ResponseType>
callback to convert ResponseType into FileUploadStatusResponse
final
statusPath StatusPathCallback
path used on status
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
present(XFile file) Future<FileUploadPresentationResponse>
the method to present the file; before uploading the chunks, the file is presented and needs FileUploadPresentationResponse.
inherited
status(FileUploadPresentationResponse presentation) Future<FileUploadStatusResponse>
the method that, given the presentation id, allows requesting the file's state.
inherited
toString() String
A string representation of this object.
inherited
uploadChunk(FileUploadPresentationResponse presentation, FileChunk chunk, {ProgressCallback? onProgress}) Future<void>
method to handle the upload of a FileChunk.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited