file property

  1. @Deprecated('instead use originalFile')
XFile get file
inherited

The file to upload.

The file may differ from the one that will be sent if any transformations have been applied.

Implementation

@Deprecated('instead use originalFile')
XFile get file => originalFile;