present abstract method

Future<FileUploadPresentationResponse> present(
  1. XFile file
)
inherited

the method to present the file; before uploading the chunks, the file is presented and needs FileUploadPresentationResponse.

FileUploadPresentationResponse.id will be used as a reference for chunk uploads.

Implementation

Future<FileUploadPresentationResponse> present(XFile file);