status abstract method

Future<FileUploadStatusResponse> status(
  1. FileUploadPresentationResponse presentation
)
inherited

the method that, given the presentation id, allows requesting the file's state.

The file's state will return FileUploadStatusResponse. This is needed to support retrying from the last unsent chunk.

presentation is the response of the present method.

controller.retry(); // under the hood status is called and the upload is retried from the last unsent chunk

Implementation

Future<FileUploadStatusResponse> status(
  FileUploadPresentationResponse presentation,
);