dio_file_uploader library
A en_file_uploader plugin to handle via dio the file upload.
Classes
- DioChunkedFileHandler
- DioChunkedFileHandler handle the file upload in chunks
- DioFileHandler
-
DioFileHandler handle the file upload using the
dio.Dio.request - DioRestorableChunkedFileHandler
- DioRestorableChunkedFileHandler handle the file upload in chunk with the capability to retry the upload from the last chunk sent.
-
SocketChunkedFileHandler<
ResponseType> - A common interface for any plugin that wants to handle file uploads using a socket client.
-
SocketFileHandler<
ResponseType> - A common interface for any plugin that wants to handle file uploads using a socket client.
-
SocketRestorableChunkedFileHandler<
ResponseType> - A common interface for any plugin that wants to handle file uploads using a socket client.
Typedefs
-
ChunkHeadersCallback
= Map<
String, String> Function(FileChunk chunk) -
compose request
headersfromFileChunk -
ChunkParser<
T> = ChunkParser< Response< T> > - callback to validate chunk upload
- ChunkPathCallback = String Function(FileUploadPresentationResponse presentation, FileChunk chunk)
-
compose request upload chunks
pathfrom onFileUploadPresentationResponseandFileChunk -
FileHeadersCallback
= Map<
String, String> ? Function(XFile file) -
compose request
headersfromXFile -
PresentHeadersCallback
= Map<
String, String> Function(XFile file) -
compose request
headersfromXFile -
PresentParser<
T> = PresentParser< Response< T> > -
callback to convert
dio.ResponseintoFileUploadPresentationResponse -
RestorableChunkHeadersCallback
= Map<
String, String> Function(FileUploadPresentationResponse presentation, FileChunk chunk) -
compose request upload chunks
headersfromFileUploadPresentationResponseandFileChunk -
StatusHeadersCallback
= Map<
String, String> Function(FileUploadPresentationResponse presentation) -
compose request status
headersfromFileUploadPresentationResponse -
StatusParser<
T> = StatusParser< Response< T> > -
callback to convert
dio.ResponseintoFileUploadStatusResponse - StatusPathCallback = String Function(FileUploadPresentationResponse presentation)
-
compose request status
pathfrom onFileUploadPresentationResponse