SocketRestorableChunkedFileHandler<ResponseType> class
abstract
A common interface for any plugin that wants to handle file uploads using a socket client.
- Implementers
Constructors
-
SocketRestorableChunkedFileHandler({required XFile file, required String presentPath, required ChunkPathCallback chunkPath, required StatusPathCallback statusPath, required PresentParser<
ResponseType> presentParser, required StatusParser<ResponseType> statusParser, int? chunkSize, String presentMethod = kPresentMethod, String chunkMethod = kChunkMethod, String statusMethod = kStatusMethod, Map<String, String> ? presentHeaders, PresentHeadersCallback? presentHeadersCallback, RestorableChunkHeadersCallback? chunkHeaders, StatusHeadersCallback? statusHeaders, String? presentBody, String? chunkBody, String? statusBody, String fileKey = kFileKey, ChunkParser<ResponseType> chunkParser = kChunkParser}) -
A common interface for any plugin that wants to handle
file uploads using a socket client.
const
Properties
- chunkBody → String?
-
bodyused on chunk uploadfinal - chunkHeaders → RestorableChunkHeadersCallback?
-
headersused on chunk uploadfinal - chunkMethod → String
-
methodused on chunk uploadfinal -
chunkParser
→ ChunkParser<
ResponseType> -
callback to validate chunk upload
final
- chunkPath → ChunkPathCallback
-
pathused on chunk uploadfinal - chunkSize → int?
-
chunk size, if null
defaultChunkSizeis usedfinalinherited - file → XFile
-
The file to upload.
no setterinherited
- fileKey → String
-
request key for file
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalFile → XFile
-
The file to upload.
finalinherited
- presentBody → String?
-
bodyused on presentationfinal -
presentHeaders
→ Map<
String, String> ? -
headersused on presentationfinal - presentHeadersCallback → PresentHeadersCallback?
-
headersused on presentationfinal - presentMethod → String
-
methodused on presentationfinal -
presentParser
→ PresentParser<
ResponseType> -
callback to convert
ResponseTypeintoFileUploadPresentationResponsefinal - presentPath → String
-
pathused on presentationfinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusBody → String?
-
bodyused on statusfinal - statusHeaders → StatusHeadersCallback?
-
headersused on statusfinal - statusMethod → String
-
methodused on statusfinal -
statusParser
→ StatusParser<
ResponseType> -
callback to convert
ResponseTypeintoFileUploadStatusResponsefinal - statusPath → StatusPathCallback
-
pathused on statusfinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
present(
XFile file) → Future< FileUploadPresentationResponse> -
the method to present the file; before uploading the chunks, the file
is presented and needs
FileUploadPresentationResponse.inherited -
status(
FileUploadPresentationResponse presentation) → Future< FileUploadStatusResponse> -
the method that, given the presentation id,
allows requesting the file's state.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadChunk(
FileUploadPresentationResponse presentation, FileChunk chunk, {ProgressCallback? onProgress}) → Future< void> -
method to handle the upload of a
FileChunk.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited