SocketRestorableChunkedFileHandler<ResponseType> constructor
const
SocketRestorableChunkedFileHandler<ResponseType> ({
- required XFile file,
- required String presentPath,
- required ChunkPathCallback chunkPath,
- required StatusPathCallback statusPath,
- required PresentParser<
ResponseType> presentParser, - required StatusParser<
ResponseType> statusParser, - int? chunkSize,
- String presentMethod = kPresentMethod,
- String chunkMethod = kChunkMethod,
- String statusMethod = kStatusMethod,
- Map<
String, String> ? presentHeaders, - PresentHeadersCallback? presentHeadersCallback,
- RestorableChunkHeadersCallback? chunkHeaders,
- StatusHeadersCallback? statusHeaders,
- String? presentBody,
- String? chunkBody,
- String? statusBody,
- String fileKey = kFileKey,
- ChunkParser<
ResponseType> chunkParser = kChunkParser,
A common interface for any plugin that wants to handle file uploads using a socket client.
set chunkSize to choose the size of the chunks else
defaultChunkSize is used
Implementation
const SocketRestorableChunkedFileHandler({
required super.file,
required this.presentPath,
required this.chunkPath,
required this.statusPath,
required this.presentParser,
required this.statusParser,
super.chunkSize,
this.presentMethod = kPresentMethod,
this.chunkMethod = kChunkMethod,
this.statusMethod = kStatusMethod,
this.presentHeaders,
this.presentHeadersCallback,
this.chunkHeaders,
this.statusHeaders,
this.presentBody,
this.chunkBody,
this.statusBody,
this.fileKey = kFileKey,
this.chunkParser = kChunkParser,
});