file property
The file to upload.
The file may differ from the one that will be sent if any transformations have been applied.
Implementation
@Deprecated('instead use originalFile')
XFile get file => originalFile;
The file to upload.
The file may differ from the one that will be sent if any transformations have been applied.
@Deprecated('instead use originalFile')
XFile get file => originalFile;